@@ -3,7 +3,7 @@ package Labyrinth::Plugin::CPAN;
 use strict;
 use warnings;
 
-our $VERSION = '3.53';
+our $VERSION = '3.54';
 
 =head1 NAME
 
@@ -39,7 +39,7 @@ my (%DBX,%TESTER,%TESTERS);
 #----------------------------------------------------------------------------
 # Public Interface Functions
 
-__PACKAGE__->mk_accessors(qw( perls osnames exceptions symlinks merged ignore ));
+__PACKAGE__->mk_accessors(qw( perls osnames exceptions symlinks merged ignore distindex ));
 
 =head1 METHODS
 
@@ -72,6 +72,16 @@ and/or purposes.
 
 Given an operating system string, returns the values used in the system.
 
+=item DistIndex
+
+Given a distribution name and a version, returns the index value used by the 
+system.
+
+=item OnCPAN
+
+Given a distribution name and a version, returns whether stored on CPAN (1) or 
+not (0).
+
 =back
 
 =cut
@@ -130,6 +140,14 @@ sub Configure {
         $OSNAMES->{lc $row->{osname}} = $row->{ostitle};
     }
     $self->osnames($OSNAMES);
+
+    my $INDEX = {};
+    @rows = $dbi->GetQuery('hash','AllDistIndices');
+    for my $row (@rows) {
+        $INDEX->{$row->{dist}}{$row->{version}}{id}   = $row->{uploadid};
+        $INDEX->{$row->{dist}}{$row->{version}}{type} = $row->{type};
+    }
+    $self->distindex($INDEX);
 }
 
 #----------------------------------------------------------------------------
@@ -213,6 +231,26 @@ sub OSName {
     return(($OSNAMES->{$code} || uc($name)), $code);
 }
 
+sub DistIndex {
+    my ($self,$dist,$version) = @_;
+    return 0    unless(defined $dist && defined $version);
+
+    my $INDEX = $self->distindex;
+    return $INDEX->{$dist}{$version}{id} || 0;
+}
+
+sub OnCPAN {
+    my ($self,$dist,$version) = @_;
+    return  unless(defined $dist && defined $version);
+
+    my $INDEX = $self->distindex;
+    my $type = $INDEX->{$dist}{$version}{type} || undef;
+
+    return 1    unless($type);          # assume it's a new release
+    return 0    if($type eq 'backpan'); # on backpan only
+    return 1;                           # on cpan or new upload
+}
+
 #----------------------------------------------------------------------------
 # Private Interface Functions
 
@@ -276,7 +314,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2008-2014 Barbie for Miss Barbell Productions
+  Copyright (C) 2008-2015 Barbie for Miss Barbell Productions
   All Rights Reserved.
 
   This distribution is free software; you can redistribute it and/or
